/*  $Id: TestApp.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import java.io.ByteArrayInputStream;
import org.junit.*;
import static org.junit.Assert.*;
import net.eduvax.util.App;
import net.eduvax.util.ConsoleErrHandler;
import net.eduvax.util.ErrHandlerFactory;
import net.eduvax.util.Error;
import net.eduvax.util.ErrorHandler;


public class TestApp {
		@Before public void setUp() {
			App.init();
		}
		@After public void tearDown() {
		}
        @Test public void testTrace() {
            App.TRACE("test trace");
        }
        @Test public void testWD() {
            App.TRACE("FILE: "+App.get().getFile("file"));
            App.TRACE("FILE: "+App.get().getFile("dir/file"));
            App.TRACE("FILE: "+App.get().getFile("../dir/file"));
            App.TRACE("FILE: "+App.get().getFile("/etc/passwd"));
            App.get().setWorkingDir("../jars");
            App.TRACE("FILE: "+App.get().getFile("file"));
            App.TRACE("FILE: "+App.get().getFile("dir/file"));
            App.TRACE("FILE: "+App.get().getFile("../dir/file"));
            App.TRACE("FILE: "+App.get().getFile("/etc/passwd"));
            App.get().setWorkingDir("/etc");
            App.TRACE("FILE: "+App.get().getFile("file"));
            App.TRACE("FILE: "+App.get().getFile("dir/file"));
            App.TRACE("FILE: "+App.get().getFile("../dir/file"));
            App.TRACE("FILE: "+App.get().getFile("/etc/passwd"));
            App.get().setWorkingDir(".");
            App.TRACE("FILE: "+App.get().getFile("file"));
            App.TRACE("FILE: "+App.get().getFile("dir/file"));
            App.TRACE("FILE: "+App.get().getFile("../dir/file"));
            App.TRACE("FILE: "+App.get().getFile("/etc/passwd"));
        }
		@Test public void testSingleton () {
			String s1="singleton 1";
			String s2="singleton 2";
			App app=App.get();
			app.setSingleton(s1);
			app.setSingleton(s2);
			app.setSingleton(getClass(),s2);
			assertTrue("singleton 1 control",s1==app.getSingleton(String.class));
			assertTrue("singleton 2 control",s2==app.getSingleton(getClass()));
		}
        @Test public void testErrorHandler() {
			App app=App.get();
            ErrorHandler eh = app.getErrHandler(ErrHandlerFactory.M_NONE);
            assertTrue("new handler don't report error",eh.checkOnly());
            eh.handle(new Error("TESTErr",Error.ELevel.WARN));
            assertFalse("handler report error after handling error",eh.checkAndReset());
            assertTrue("handler don't report error at 2nd consecutive checkAndReseet",eh.checkAndReset());
            byte[] resp1={'z','\n','y','\n','n','\n'};
            eh=new ConsoleErrHandler(ErrHandlerFactory.M_IGNORE,
                    new ByteArrayInputStream(resp1),System.out);
            eh.handle(new Error("TESTErr",Error.ELevel.ERR));
            assertTrue("check M_IGNORE mode without error",eh.checkAndReset());
            eh.handle(new Error("TESTErr",Error.ELevel.ERR));
            assertTrue("check M_IGNORE mode with error",eh.checkAndReset());
            byte[] resp2={'r','\n'};
            eh=new ConsoleErrHandler(ErrHandlerFactory.M_RETRY,
                    new ByteArrayInputStream(resp2),System.out);
            eh.handle(new Error("TESTErr",Error.ELevel.ERR));
            assertTrue("check M_RETRY mode",eh.checkAndReset());
        }
}
